// $Id: LinkLayer.java,v 1.3 2001/06/04 00:44:48 pcharles Exp $

/***************************************************************************
 * Copyright (C) 2001, Patrick Charles and Jonas Lehmann                   *
 * Distributed under the Mozilla Public License                            *
 *   http://www.mozilla.org/NPL/MPL-1.1.txt                                *
 ***************************************************************************/
package net.sourceforge.jpcap.net;

import java.util.HashMap;


/**
 * Information about network link layers.
 *
 * @author Patrick Charles and Jonas Lehmann
 * @version $Revision: 1.3 $
 * @lastModifiedBy $Author: pcharles $
 * @lastModifiedAt $Date: 2001/06/04 00:44:48 $
 */
public class LinkLayer implements LinkLayers
{
  /**
   * Fetch the header length associated with various link-layer types.
   * @param layerType the link-layer code
   * @return the length of the header for the specified link-layer
   */
  public static int getLinkLayerLength(int layerType) {
    switch(layerType) {
    case EN10MB: 
      return 14;
    case FDDI: 
      return 21;
    case NULL: 
    default:
      return 0;
    }
  }

  /**
   * Fetch a link-layer type description.
   * @param code the code associated with the description.
   * @return a description of the link-layer type.
   */
  public static String getDescription(int code) {
    Integer c = new Integer(code);
    if(descriptions.containsKey(c)) 
      return (String)descriptions.get(c);
    else 
      return "unknown";
  }

  /**
   * 'Human-readable' link-layer type descriptions.
   */
  private static HashMap descriptions = new HashMap();
  static {
    descriptions.put(new Integer(NULL), "no link-layer encapsulation");
    descriptions.put(new Integer(EN10MB), "10/100Mb ethernet");
    descriptions.put(new Integer(EN3MB), "3Mb experimental ethernet");
    descriptions.put(new Integer(AX25), "AX.25 amateur radio");
    descriptions.put(new Integer(PRONET), "proteon pronet token ring");
    descriptions.put(new Integer(CHAOS), "chaos");
    descriptions.put(new Integer(IEEE802), "IEEE802 network");
    descriptions.put(new Integer(ARCNET), "ARCNET");
    descriptions.put(new Integer(SLIP), "serial line IP");
    descriptions.put(new Integer(PPP), "point-to-point protocol");
    descriptions.put(new Integer(FDDI), "FDDI");
    descriptions.put(new Integer(ATM_RFC1483), "LLC/SNAP encapsulated ATM");
    descriptions.put(new Integer(RAW), "raw IP");
    descriptions.put(new Integer(UNKNOWN), "unknown link-layer type");
  }


  private String _rcsid = 
    "$Id: LinkLayer.java,v 1.3 2001/06/04 00:44:48 pcharles Exp $";
}
