// $Id: UDPPacket.java,v 1.9 2001/06/21 08:15:23 pcharles Exp $

/***************************************************************************
 * Copyright (C) 2001, Patrick Charles and Jonas Lehmann                   *
 * Distributed under the Mozilla Public License                            *
 *   http://www.mozilla.org/NPL/MPL-1.1.txt                                *
 ***************************************************************************/
package net.sourceforge.jpcap.net;

import net.sourceforge.jpcap.util.AnsiEscapeSequences;
import net.sourceforge.jpcap.util.ArrayHelper;


/**
 * A UDP packet.
 * <p>
 * Extends an IP packet, adding a UDP header and UDP data payload.
 *
 * @author Patrick Charles and Jonas Lehmann
 * @version $Revision: 1.9 $
 * @lastModifiedBy $Author: pcharles $
 * @lastModifiedAt $Date: 2001/06/21 08:15:23 $
 */
public class UDPPacket extends IPPacket implements UDPFields
{
  /**
   * Create a new UDP packet.
   */
  public UDPPacket(int lLen, byte [] bytes) {
    super(lLen, bytes);

    int offset = lLen + IP_HEADER_LEN;
    this.header = PacketEncoding.extractHeader(offset, UDP_HEADER_LEN, bytes);
    this.data = PacketEncoding.extractData(offset, UDP_HEADER_LEN, bytes);
  }

  /**
   * Fetch the port number on the source host.
   */
  public int getSourcePort() {
    return ArrayHelper.extractInteger(header, UDP_SP_POS, UDP_PORT_LEN);
  }

  /**
   * Fetch the port number on the target host.
   */
  public int getDestinationPort() {
    return ArrayHelper.extractInteger(header, UDP_DP_POS, UDP_PORT_LEN);
  }

  /**
   * Fetch the total length of the UDP packet, including header and
   * data payload, in bytes.
   */
  public int getLength() {
    // should produce the same value as header.length + data.length
    return ArrayHelper.extractInteger(header, UDP_LEN_POS, UDP_LEN_LEN);
  }

  /**
   * Fetch the header checksum.
   */
  public int getChecksum() {
    return ArrayHelper.extractInteger(header, UDP_CSUM_POS, UDP_CSUM_LEN);
  }

  /**
   * Fetch the udp header, excluding udp data payload.
   */
  public byte [] getHeader() {
    return header;
  }

  /**
   * Fetch data portion of the udp header.
   */
  public byte [] getData() {
    return data;
  }

  /**
   * Convert this UDP packet to a readable string.
   */
  public String toString() {
    StringBuffer buffer = new StringBuffer();
    buffer.append('[');
    buffer.append(AnsiEscapeSequences.LIGHT_GREEN);
    buffer.append("UDPPacket");
    buffer.append(AnsiEscapeSequences.RESET);
    buffer.append(": ");
    buffer.append(getSourceAddress());
    buffer.append('.');
    buffer.append(IPPort.getName(getSourcePort()));
    buffer.append(" -> ");
    buffer.append(getDestinationAddress());
    buffer.append('.');
    buffer.append(IPPort.getName(getDestinationPort()));
    buffer.append(" l=" + header.length + "," + data.length);
    buffer.append(']');

    return buffer.toString();
  }


  /**
   * UDP header.
   */
  byte [] header;

  /**
   * UDP data.
   */
  byte [] data;

  private String _rcsid = 
    "$Id: UDPPacket.java,v 1.9 2001/06/21 08:15:23 pcharles Exp $";
}
